% Generate reduced basis using a greedy algorithm based on maximum
% residual of the (current) reduced basis solution, where the search
% is done over a set of n_search randomly chosen parameters (the training
% set

% Size of spatial discretization, number of parameters
dim_sp  = nint;   %length(K{1});
dim_par = noarv;
fxi = fnew(1:dim_sp);   

% Training set of parameters, and error tolerance
n_train = 3000;
tol_rb = (1.d-5)*norm(fxi(1:dim_sp));

fprintf('Building reduced basis using %i training points\n',n_train); 
xi_set = 2*rand(dim_par,n_train) - 1;

% Maximum size of pre-allocated reduced basis
max_rdim = 100;
Q = zeros(dim_sp,max_rdim);

%rand('twister',22154);
%xi = .5*ones(dim_par,1);  % rand(dim_par,1);

% Initialize reduced basis using mean of parameter set (=0)
Kxi = K{1};
u = Kxi\fxi;
Q(:,1) = u/norm(u);
rb_size = 1;
Qrb = Q(:,1:rb_size);

% Maximum error for initial reduced basis
Kr = K_reduced(K,Qrb,dim_par);
[r,u_max] = error_max(K,Kr,Qrb,fxi,xi_set,dim_par); 

% Augment reduced basis using full solution for parameter producing 
% maximal error of reduced solution for current basis
while r>tol_rb,
   rb_size = rb_size+1;
   Q(:,rb_size) = u_max;
   Qrb = orth(Q(:,1:rb_size));
   Kr = K_reduced(K,Qrb,dim_par);
   [r,u_max] = error_max(K,Kr,Qrb,fxi,xi_set,dim_par); 
end 

fprintf('Reduced basis of size %i constructed \n',rb_size);