function [e_max,u_max] = error_max(K,Kr,Q,f,xi_set,dim_par)
% Find maximal error of reduced solutions for all parameters in training
% set
%
% Input:   K        cell array of components of coefficient matrix
%          Kr       cell array of components reduced matrix
%          Q        matrix whose columns correspond to the (current) 
%                   reduced basis
%          xi_set   training set of parameters (dimensions dim_par x
%                   n_train)
%          dim_par  number of parameters
%
% Output:  e_max    maximum error of reduced solutions for all parameters
%                   in training set
%          u_max    reducedsolution with maximal error

e_max = 0;

% Find largest value of (residual) error indicator on the training set, 
% and associated parameter
for i=1:size(xi_set,2),
   xi = xi_set(:,i);
   Kxi   = K{1};
   Kr_xi = Kr{1};
   for j=1:dim_par,
      Kxi   = Kxi   + K{j+1}*xi(j);
      Kr_xi = Kr_xi + Kr{j+1}*xi(j);
   end
   u = Q*(Kr_xi\(Q'*f));
   e = norm(f-Kxi*u);
   if e>e_max,
      e_max = e;
      index_max = i;
   end
end

% Compute full solution for parameter xi at which the error for the 
% reduced solution is maximal on the training set
xi = xi_set(:,index_max);
Kxi = K{1};
for j=1:dim_par,
   Kxi = Kxi + K{j+1}*xi(j);
end
u_max = Kxi\f;